@@ -20,6 +20,10 @@ class Discovery(DiscoveryBase):
     def batch_api(self) -> api_client.BatchApi:
         return self._configure_api_client(api_client, "BatchApi")
 
+    @property
+    def gdpr_api(self) -> api_client.GDPRApi:
+        return self._configure_api_client(api_client, "GDPRApi")
+
     @property
     def feedback_submissions(self):
         return FeedbackSubmissionsDiscovery(self.config)
